emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[ELPA-diffs] ELPA branch, master, updated. 5a3d6b937f455e75253f6736ba58a


From: Leo Liu
Subject: [ELPA-diffs] ELPA branch, master, updated. 5a3d6b937f455e75253f6736ba58a4dfb786721a
Date: Tue, 03 Dec 2013 08:34:13 +0000

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "ELPA".

The branch, master has been updated
       via  5a3d6b937f455e75253f6736ba58a4dfb786721a (commit)
       via  8cc4ff9ea47d264ba9641a60bcdb71a085aebf9b (commit)
       via  9558ce187af9fc691a70f24c32451ee7c9f9367f (commit)
       via  83b9cd31f5bc481907a35e4a3ba4e0c25b033c43 (commit)
       via  2ea72495010241cb7226da02410d1f0a47155b8f (commit)
       via  183b5ace2f20820cf0f149d720fdfb65a818d94d (commit)
       via  ed850b0addb1d1bcabeefac962753247762a07ac (commit)
       via  ef8a5a32879310352ad47ede55b828ebbe21d7b0 (commit)
       via  c715ba62b542d2a4ad131ab2e9f0756cfa5bc65a (commit)
      from  76e545724e00d7874cc9b0ca01269b9e6cc8e493 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit 5a3d6b937f455e75253f6736ba58a4dfb786721a
Merge: 76e5457 8cc4ff9
Author: Leo Liu <address@hidden>
Date:   Tue Dec 3 16:33:46 2013 +0800

    Merge branch 'master' of github.com:leoliu/ggtags


commit 8cc4ff9ea47d264ba9641a60bcdb71a085aebf9b
Author: Leo Liu <address@hidden>
Date:   Tue Dec 3 10:30:35 2013 +0800

    Also remove "Using default configuration." in the output

diff --git a/README.rst b/README.rst
index bf02638..21595df 100644
--- a/README.rst
+++ b/README.rst
@@ -38,9 +38,9 @@ between a few tools.
 Screenshot
 ~~~~~~~~~~
 
-.. figure:: http://i.imgur.com/lwED3aD.png
+.. figure:: http://i.imgur.com/E5Gr56m.png
    :width: 500px
-   :target: http://i.imgur.com/lwED3aD.png
+   :target: http://i.imgur.com/E5Gr56m.png
    :alt: ggtags.png
 
 Config
diff --git a/ggtags.el b/ggtags.el
index 403e690..2678943 100644
--- a/ggtags.el
+++ b/ggtags.el
@@ -530,12 +530,10 @@ non-nil."
          (display-buffer-overriding-action
           (if (not ggtags-auto-jump-to-first-match)
               display-buffer-overriding-action
-            (cons (lambda (buf action)
-                    (and (assq 'no-display-ok (cdr action))
-                         (with-current-buffer buf
-                           (derived-mode-p 'ggtags-global-mode))))
-                  ;; Suppress `display-buffer'.
-                  (list (lambda (&rest _) 'dont-display))))))
+            (cons (lambda (buf _action)
+                    (with-current-buffer buf
+                      (derived-mode-p 'ggtags-global-mode)))
+                  (list #'display-buffer-no-window)))))
     (setq ggtags-global-start-marker (point-marker))
     (ggtags-navigation-mode +1)
     (setq ggtags-global-exit-status 0
@@ -919,7 +917,7 @@ Global and Emacs."
   (when (and (> ggtags-global-output-lines 5)
              (not (get-buffer-window (current-buffer))))
     (let* ((split-window-preferred-function ggtags-split-window-function)
-           (w (display-buffer (current-buffer) '(nil (no-display-ok . t)))))
+           (w (display-buffer (current-buffer) '(nil (allow-no-window . t)))))
       (and w (compilation-set-window-height w))))
   (make-local-variable 'ggtags-global-large-output)
   (when (> ggtags-global-output-lines ggtags-global-large-output)

commit 83b9cd31f5bc481907a35e4a3ba4e0c25b033c43
Author: Leo Liu <address@hidden>
Date:   Wed Nov 20 22:52:34 2013 +0800

    Customisable use of tag table for completion at point

diff --git a/ggtags.el b/ggtags.el
index 6dbe59e..403e690 100644
--- a/ggtags.el
+++ b/ggtags.el
@@ -189,6 +189,12 @@ properly update `ggtags-mode-map'."
   :type 'key-sequence
   :group 'ggtags)
 
+(defcustom ggtags-enable-completion-at-point t
+  "Non-nil to enable completion at point using the tag table."
+  :safe 'booleanp
+  :type 'boolean
+  :group 'ggtags)
+
 (defcustom ggtags-completing-read-function completing-read-function
   "Ggtags specific `completing-read-function' (which see)."
   :type 'function
@@ -463,6 +469,12 @@ non-nil."
                      "\n" t)))))
      (cdr ggtags-completion-cache))))
 
+(defun ggtags-completion-at-point ()
+  "A function for `completion-at-point-functions'."
+  (when-let (bounds (funcall ggtags-bounds-of-tag-function))
+    (and (< (car bounds) (cdr bounds))
+         (list (car bounds) (cdr bounds) ggtags-completion-table))))
+
 (defun ggtags-read-tag ()
   (ggtags-ensure-project)
   (let ((default (ggtags-tag-at-point))
@@ -1260,9 +1272,13 @@ Global and Emacs."
   (if ggtags-mode
       (progn
         (add-hook 'after-save-hook 'ggtags-after-save-function nil t)
+        (when ggtags-enable-completion-at-point
+          (add-hook 'completion-at-point-functions
+                    #'ggtags-completion-at-point nil t))
         (or (executable-find "global")
             (message "Failed to find GNU Global")))
     (remove-hook 'after-save-hook 'ggtags-after-save-function t)
+    (remove-hook 'completion-at-point-functions #'ggtags-completion-at-point t)
     (and (overlayp ggtags-highlight-tag-overlay)
          (delete-overlay ggtags-highlight-tag-overlay))
     (setq ggtags-highlight-tag-overlay nil)))

commit 2ea72495010241cb7226da02410d1f0a47155b8f
Author: Leo Liu <address@hidden>
Date:   Wed Nov 20 08:09:50 2013 +0800

    Refactor ggtags-ensure-project for ggtags-create-tags

diff --git a/ggtags.el b/ggtags.el
index ab78c5e..6dbe59e 100644
--- a/ggtags.el
+++ b/ggtags.el
@@ -354,6 +354,13 @@ properly update `ggtags-mode-map'."
 (defun ggtags-check-project ()
   (or (ggtags-find-project) (error "File GTAGS not found")))
 
+(defun ggtags-ensure-project ()
+  (or (ggtags-find-project)
+      (when (or (yes-or-no-p "File GTAGS not found; run gtags? ")
+                (user-error "Aborted"))
+        (call-interactively #'ggtags-create-tags)
+        (ggtags-find-project))))
+
 (defun ggtags-save-project-settings (&optional noconfirm)
   "Save Gnu Global's specific environment variables."
   (interactive "P")
@@ -406,26 +413,23 @@ properly update `ggtags-mode-map'."
       (message "Project read-only-mode is %s" (if val "on" "off")))
     val))
 
-(defun ggtags-ensure-project ()
-  (interactive)
-  (or (ggtags-find-project)
-      (when (or (yes-or-no-p "File GTAGS not found; run gtags? ")
-                (user-error "Aborted"))
-        (let ((root (read-directory-name "Directory: " nil nil t))
-              (process-environment process-environment))
-          (and (zerop (length root)) (user-error "No directory chosen"))
-          (setenv "GTAGSROOT"
-                  (directory-file-name (file-name-as-directory root)))
-          (ggtags-with-process-environment
-           (and (not (getenv "GTAGSLABEL"))
-                (yes-or-no-p "Use `ctags' backend? ")
-                (setenv "GTAGSLABEL" "ctags"))
-           (with-temp-message "`gtags' in progress..."
-             (let ((default-directory (file-name-as-directory root)))
-               (apply #'ggtags-process-string
-                      "gtags" (and ggtags-use-idutils '("--idutils"))))))
-          (message "GTAGS generated in `%s'" root)
-          (ggtags-find-project)))))
+(defun ggtags-create-tags (root)
+  "Run `gtags' in directory ROOT to create tag files."
+  (interactive "DRoot directory: ")
+  (let ((process-environment process-environment))
+    (when (zerop (length root)) (error "No root directory provided"))
+    (setenv "GTAGSROOT"
+            (directory-file-name (file-name-as-directory root)))
+    (ggtags-with-process-environment
+     (and (not (getenv "GTAGSLABEL"))
+          (yes-or-no-p "Use `ctags' backend? ")
+          (setenv "GTAGSLABEL" "ctags"))
+     (with-temp-message "`gtags' in progress..."
+       (let ((default-directory (file-name-as-directory root)))
+         (apply #'ggtags-process-string
+                "gtags" (and ggtags-use-idutils '("--idutils"))))))
+    (message "GTAGS generated in `%s'" root)
+    root))
 
 (defun ggtags-update-tags (&optional force)
   "Update GNU Global tag database.
@@ -1242,7 +1246,7 @@ Global and Emacs."
       '(menu-item "Update tag files" ggtags-update-tags
                   :visible (ggtags-find-project)))
     (define-key menu [run-gtags]
-      '(menu-item "Run gtags" ggtags-ensure-project
+      '(menu-item "Run gtags" ggtags-create-tags
                   :visible (not (ggtags-find-project))))
     map))
 

commit 183b5ace2f20820cf0f149d720fdfb65a818d94d
Author: Leo Liu <address@hidden>
Date:   Wed Nov 20 07:11:54 2013 +0800

    Improve last change to observe ggtags-global-window-height

diff --git a/ggtags.el b/ggtags.el
index bbf97be..ab78c5e 100644
--- a/ggtags.el
+++ b/ggtags.el
@@ -902,9 +902,12 @@ Global and Emacs."
         (count-lines compilation-filter-start (point)))
   (when (and (> ggtags-global-output-lines 5)
              (not (get-buffer-window (current-buffer))))
-    (let ((split-window-preferred-function ggtags-split-window-function))
-      (display-buffer (current-buffer))))
+    (let* ((split-window-preferred-function ggtags-split-window-function)
+           (w (display-buffer (current-buffer) '(nil (no-display-ok . t)))))
+      (and w (compilation-set-window-height w))))
+  (make-local-variable 'ggtags-global-large-output)
   (when (> ggtags-global-output-lines ggtags-global-large-output)
+    (incf ggtags-global-large-output 500)
     (let ((message-log-max nil))
       (message "Output %d lines (Type `C-c C-k' to cancel)"
                ggtags-global-output-lines))))

commit ed850b0addb1d1bcabeefac962753247762a07ac
Author: Leo Liu <address@hidden>
Date:   Tue Nov 19 11:50:13 2013 +0800

    Fix #19: display buffer promptly in case of multiple matches

diff --git a/ggtags.el b/ggtags.el
index ad61c1c..bbf97be 100644
--- a/ggtags.el
+++ b/ggtags.el
@@ -900,6 +900,10 @@ Global and Emacs."
   (ansi-color-apply-on-region compilation-filter-start (point))
   (incf ggtags-global-output-lines
         (count-lines compilation-filter-start (point)))
+  (when (and (> ggtags-global-output-lines 5)
+             (not (get-buffer-window (current-buffer))))
+    (let ((split-window-preferred-function ggtags-split-window-function))
+      (display-buffer (current-buffer))))
   (when (> ggtags-global-output-lines ggtags-global-large-output)
     (let ((message-log-max nil))
       (message "Output %d lines (Type `C-c C-k' to cancel)"

commit ef8a5a32879310352ad47ede55b828ebbe21d7b0
Author: Leo Liu <address@hidden>
Date:   Tue Nov 19 11:05:17 2013 +0800

    Fix #19: suppress displaying buffer for 0 or 1 match
    
    See also: http://debbugs.gnu.org/13594

diff --git a/README.rst b/README.rst
index 4b0f84b..bf02638 100644
--- a/README.rst
+++ b/README.rst
@@ -102,10 +102,3 @@ Bugs
 ~~~~
 
 https://github.com/leoliu/ggtags/issues
-
-known problems
-++++++++++++++
-
-When there is only one match a window is still popped up to be closed
-immediately due to a `bug <http://debbugs.gnu.org/13594>`_ in
-``compile.el``.
diff --git a/ggtags.el b/ggtags.el
index 061e571..ad61c1c 100644
--- a/ggtags.el
+++ b/ggtags.el
@@ -3,7 +3,7 @@
 ;; Copyright (C) 2013  Free Software Foundation, Inc.
 
 ;; Author: Leo Liu <address@hidden>
-;; Version: 0.7.6
+;; Version: 0.7.7
 ;; Keywords: tools, convenience
 ;; Created: 2013-01-29
 ;; URL: https://github.com/leoliu/ggtags
@@ -509,7 +509,17 @@ non-nil."
 
 (defun ggtags-global-start (command &optional root)
   (let* ((default-directory (or root (ggtags-current-project-root)))
-         (split-window-preferred-function ggtags-split-window-function))
+         (split-window-preferred-function ggtags-split-window-function)
+         ;; See http://debbugs.gnu.org/13594
+         (display-buffer-overriding-action
+          (if (not ggtags-auto-jump-to-first-match)
+              display-buffer-overriding-action
+            (cons (lambda (buf action)
+                    (and (assq 'no-display-ok (cdr action))
+                         (with-current-buffer buf
+                           (derived-mode-p 'ggtags-global-mode))))
+                  ;; Suppress `display-buffer'.
+                  (list (lambda (&rest _) 'dont-display))))))
     (setq ggtags-global-start-marker (point-marker))
     (ggtags-navigation-mode +1)
     (setq ggtags-global-exit-status 0

commit c715ba62b542d2a4ad131ab2e9f0756cfa5bc65a
Author: Leo Liu <address@hidden>
Date:   Tue Nov 19 10:58:13 2013 +0800

    Stricter regexp in ggtags-delete-tag-files
    
    or it may match too many files on case-insensitive file systems.

diff --git a/ggtags.el b/ggtags.el
index 0f822a3..061e571 100644
--- a/ggtags.el
+++ b/ggtags.el
@@ -647,8 +647,10 @@ Global and Emacs."
   "Delete the tag files generated by gtags."
   (interactive)
   (when (ggtags-current-project-root)
-    (let ((files (directory-files (ggtags-current-project-root) t
-                                  (regexp-opt '("GPATH" "GRTAGS" "GTAGS" 
"ID"))))
+    (let ((files (directory-files
+                  (ggtags-current-project-root) t
+                  (concat "\\`" (regexp-opt '("GPATH" "GRTAGS" "GTAGS" "ID"))
+                          "\\'")))
           (buffer "*GTags File List*"))
       (or files (user-error "No tag files found"))
       (with-output-to-temp-buffer buffer

-----------------------------------------------------------------------

Summary of changes:
 packages/ggtags/README.rst |   11 +----
 packages/ggtags/ggtags.el  |   95 +++++++++++++++++++++++++++++++-------------
 2 files changed, 69 insertions(+), 37 deletions(-)


hooks/post-receive
diff --git a/ggtags.el b/ggtags.el
index 2678943..f01400c 100644
--- a/ggtags.el
+++ b/ggtags.el
@@ -907,9 +907,11 @@ Global and Emacs."
 
 (defun ggtags-global-filter ()
   "Called from `compilation-filter-hook' (which see)."
-  ;; Get rid of line "Using config file '/PATH/TO/.globalrc'."
-  (when (re-search-backward "^ *Using config file '.*\n"
-                            compilation-filter-start t)
+  ;; Get rid of line "Using config file '/PATH/TO/.globalrc'." or
+  ;; "Using default configuration."
+  (when (re-search-backward
+         "^ *Using \\(?:config file '.*\\|default configuration.\\)\n"
+         compilation-filter-start t)
     (replace-match ""))
   (ansi-color-apply-on-region compilation-filter-start (point))
   (incf ggtags-global-output-lines

commit 9558ce187af9fc691a70f24c32451ee7c9f9367f
Author: Leo Liu <address@hidden>
Date:   Tue Dec 3 10:23:41 2013 +0800

    Fix due to renaming no-display-ok to allow-no-window

-- 
ELPA



reply via email to

[Prev in Thread] Current Thread [Next in Thread]